@@ -472,6 +472,7 @@ first_row (void)
 
 	gtk_tree_store_append (baobab.model, &firstiter, NULL);
 	size = gnome_vfs_format_file_size_for_display (g_fs.used);
+	g_assert(g_fs.total != 0);
 	perc = ((gfloat) g_fs.used * 100) / (gfloat) g_fs.total;
 	g_sprintf (textperc, " %.1f %%", perc);
 	bar = set_bar ((g_fs.used * 100) / g_fs.total);
@@ -637,6 +638,7 @@ list_find (gconstpointer a, gconstpointer b)
 gboolean
 is_excluded_dir (const gchar *dir)
 {
+		
 	return (baobab.bbExcludedDirs &&
 		(g_slist_find_custom (baobab.bbExcludedDirs, dir, list_find) != NULL));
 }
@@ -738,6 +740,17 @@ baobab_init (void)
 				 NULL, NULL, NULL);				 
 	baobab.bbExcludedDirs = gconf_client_get_list (baobab.gconf_client, PROPS_SCAN_KEY,
 						       GCONF_VALUE_STRING, NULL);
+	
+	/*	Verify if gconf wrongly contains root dir exclusion, and remove it from gconf. */
+	if (is_excluded_dir("/")) {
+		baobab.bbExcludedDirs = g_slist_delete_link (baobab.bbExcludedDirs, 
+						g_slist_find_custom(baobab.bbExcludedDirs, 
+							"/", list_find));
+		gconf_client_set_list (baobab.gconf_client, PROPS_SCAN_KEY,
+						GCONF_VALUE_STRING, 
+						baobab.bbExcludedDirs, NULL);
+	}
+	
 	baobab.bbEnableHomeMonitor = gconf_client_get_bool (baobab.gconf_client,
 							    PROPS_ENABLE_HOME_MONITOR,
 							    NULL);
@@ -841,6 +854,11 @@ main (int argc, char *argv[])
 	baobab_init ();
 
 	baobab_get_filesystem (&g_fs);
+	if (g_fs.total == 0) {
+		g_print("No mount points detected! Aborting...\n");
+		goto closing;
+		}
+	
 	set_label_scan (&g_fs);
 
 	baobab.window = glade_xml_get_widget (baobab.main_xml, "baobab_window");
@@ -884,6 +902,7 @@ main (int argc, char *argv[])
 
 	gtk_main ();
 
+ closing:
 	baobab_shutdown ();
 
 	glibtop_close ();
